@@ -56,70 +56,6 @@ extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
 
 extern VALUE mDCL;
 
-static VALUE
-dcl_stftrf(obj, ux, uy)
-    VALUE obj, ux, uy;
-{
-    real i_ux;
-    real i_uy;
-    real o_vx;
-    real o_vy;
-    VALUE vx;
-    VALUE vy;
-
-    if (TYPE(ux) != T_FLOAT) {
-      ux = rb_funcall(ux, rb_intern("to_f"), 0);
-    }
-    if (TYPE(uy) != T_FLOAT) {
-      uy = rb_funcall(uy, rb_intern("to_f"), 0);
-    }
-
-    i_ux = (real)NUM2DBL(ux);
-    i_uy = (real)NUM2DBL(uy);
-
-
-    stftrf_(&i_ux, &i_uy, &o_vx, &o_vy);
-
-    vx = rb_float_new((double)o_vx);
-    vy = rb_float_new((double)o_vy);
-
-
-    return rb_ary_new3(2, vx, vy);
-
-}
-
-static VALUE
-dcl_stitrf(obj, vx, vy)
-    VALUE obj, vx, vy;
-{
-    real i_vx;
-    real i_vy;
-    real o_ux;
-    real o_uy;
-    VALUE ux;
-    VALUE uy;
-
-    if (TYPE(vx) != T_FLOAT) {
-      vx = rb_funcall(vx, rb_intern("to_f"), 0);
-    }
-    if (TYPE(vy) != T_FLOAT) {
-      vy = rb_funcall(vy, rb_intern("to_f"), 0);
-    }
-
-    i_vx = (real)NUM2DBL(vx);
-    i_vy = (real)NUM2DBL(vy);
-
-
-    stitrf_(&i_vx, &i_vy, &o_ux, &o_uy);
-
-    ux = rb_float_new((double)o_ux);
-    uy = rb_float_new((double)o_uy);
-
-
-    return rb_ary_new3(2, ux, uy);
-
-}
-
 static VALUE
 dcl_stqtrf(obj)
     VALUE obj;
@@ -886,70 +822,6 @@ dcl_stspr3(obj, xfc, yfc, zfc, theta, phi, psi, fac, zview, rxoff, ryoff)
 
 }
 
-static VALUE
-dcl_stfpr2(obj, x, y)
-    VALUE obj, x, y;
-{
-    real i_x;
-    real i_y;
-    real o_rx;
-    real o_ry;
-    VALUE rx;
-    VALUE ry;
-
-    if (TYPE(x) != T_FLOAT) {
-      x = rb_funcall(x, rb_intern("to_f"), 0);
-    }
-    if (TYPE(y) != T_FLOAT) {
-      y = rb_funcall(y, rb_intern("to_f"), 0);
-    }
-
-    i_x = (real)NUM2DBL(x);
-    i_y = (real)NUM2DBL(y);
-
-
-    stfpr2_(&i_x, &i_y, &o_rx, &o_ry);
-
-    rx = rb_float_new((double)o_rx);
-    ry = rb_float_new((double)o_ry);
-
-
-    return rb_ary_new3(2, rx, ry);
-
-}
-
-static VALUE
-dcl_stipr2(obj, rx, ry)
-    VALUE obj, rx, ry;
-{
-    real i_rx;
-    real i_ry;
-    real o_x;
-    real o_y;
-    VALUE x;
-    VALUE y;
-
-    if (TYPE(rx) != T_FLOAT) {
-      rx = rb_funcall(rx, rb_intern("to_f"), 0);
-    }
-    if (TYPE(ry) != T_FLOAT) {
-      ry = rb_funcall(ry, rb_intern("to_f"), 0);
-    }
-
-    i_rx = (real)NUM2DBL(rx);
-    i_ry = (real)NUM2DBL(ry);
-
-
-    stipr2_(&i_rx, &i_ry, &o_x, &o_y);
-
-    x = rb_float_new((double)o_x);
-    y = rb_float_new((double)o_y);
-
-
-    return rb_ary_new3(2, x, y);
-
-}
-
 static VALUE
 dcl_stspr2(obj, ix, iy, sect)
     VALUE obj, ix, iy, sect;
@@ -1129,8 +1001,6 @@ void
 init_grph1_stpack(mDCL)
 VALUE mDCL;
 {
-    rb_define_module_function(mDCL, "stftrf", dcl_stftrf, 2);
-    rb_define_module_function(mDCL, "stitrf", dcl_stitrf, 2);
     rb_define_module_function(mDCL, "stqtrf", dcl_stqtrf, 0);
     rb_define_module_function(mDCL, "ststrf", dcl_ststrf, 1);
     rb_define_module_function(mDCL, "stftrn", dcl_stftrn, 2);
@@ -1159,8 +1029,6 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "stqwrc", dcl_stqwrc, 0);
     rb_define_module_function(mDCL, "stfpr3", dcl_stfpr3, 3);
     rb_define_module_function(mDCL, "stspr3", dcl_stspr3, 10);
-    rb_define_module_function(mDCL, "stfpr2", dcl_stfpr2, 2);
-    rb_define_module_function(mDCL, "stipr2", dcl_stipr2, 2);
     rb_define_module_function(mDCL, "stspr2", dcl_stspr2, 3);
     rb_define_module_function(mDCL, "stepr2", dcl_stepr2, 0);
     rb_define_module_function(mDCL, "strpr2", dcl_strpr2, 0);
